@@ -2,61 +2,99 @@
 #'
 #' Select the subset of predictors that do the best at meeting some
 #' well-defined objective criterion, such as having the largest R2 value or the
-#' smallest MSE, Mallow's Cp or AIC.
+#' smallest MSE, Mallow's Cp or AIC. The default metric used for selecting the
+#' model is R2 but the user can choose any of the other available metrics.
 #'
 #' @param model An object of class \code{lm}.
+#' @param max_order Maximum subset order.
+#' @param include Character or numeric vector; variables to be included in selection process.
+#' @param exclude Character or numeric vector; variables to be excluded from selection process.
+#' @param metric Metric to select model.
 #' @param x An object of class \code{ols_step_best_subset}.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #' @param ... Other inputs.
 #'
 #' @return \code{ols_step_best_subset} returns an object of class \code{"ols_step_best_subset"}.
-#' An object of class \code{"ols_step_best_subset"} is a data frame containing the
-#' following components:
+#' An object of class \code{"ols_step_best_subset"} is a list containing the following:
 #'
-#' \item{n}{model number}
-#' \item{predictors}{predictors in the model}
-#' \item{rsquare}{rsquare of the model}
-#' \item{adjr}{adjusted rsquare of the model}
-#' \item{predrsq}{predicted rsquare of the model}
-#' \item{cp}{mallow's Cp}
-#' \item{aic}{akaike information criteria}
-#' \item{sbic}{sawa bayesian information criteria}
-#' \item{sbc}{schwarz bayes information criteria}
-#' \item{gmsep}{estimated MSE of prediction, assuming multivariate normality}
-#' \item{jp}{final prediction error}
-#' \item{pc}{amemiya prediction criteria}
-#' \item{sp}{hocking's Sp}
+#' \item{metrics}{selection metrics}
 #'
 #' @references
 #' Kutner, MH, Nachtscheim CJ, Neter J and Li W., 2004, Applied Linear Statistical Models (5th edition).
 #' Chicago, IL., McGraw Hill/Irwin.
 #'
-#' @section Deprecated Function:
-#' \code{ols_best_subset()} has been deprecated. Instead use \code{ols_step_best_subset()}.
-#'
-#' @family variable selection procedures
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 #' ols_step_best_subset(model)
+#' ols_step_best_subset(model, metric = "adjr")
+#' ols_step_best_subset(model, metric = "cp")
 #'
+#' # maximum subset
+#' model <- lm(mpg ~ disp + hp + drat + wt + qsec, data = mtcars)
+#' ols_step_best_subset(model, max_order = 3)
+#' 
 #' # plot
 #' model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 #' k <- ols_step_best_subset(model)
 #' plot(k)
 #'
+#' # return only models including `qsec`
+#' ols_step_best_subset(model, include = c("qsec"))
+#'
+#' # exclude `hp` from selection process
+#' ols_step_best_subset(model, exclude = c("hp"))
+#'
 #' @export
 #'
 ols_step_best_subset <- function(model, ...) UseMethod("ols_step_best_subset")
 
 #' @export
-#'
-ols_step_best_subset.default <- function(model, ...) {
+#' @rdname ols_step_best_subset
+#' 
+ols_step_best_subset.default <- function(model, max_order = NULL, 
+                                         include = NULL, exclude = NULL,
+                                         metric = c("rsquare", "adjr", "predrsq",
+                                                    "cp", "aic", "sbic", "sbc",
+                                                    "msep", "fpe", "apc", "hsp"),
+                                         ...) {
 
   check_model(model)
-  check_npredictors(model, 3)
+  check_npredictors(model, 2)
 
-  nam   <- coeff_names(model)
+  indterms <- coeff_names(model)
+  lenterms <- length(indterms)
+
+  if (is.character(include)) {
+    npm <- include %in% indterms
+    if (!all(npm)) {
+      stop(paste(paste(include[!npm], collapse = ", "), "not part of the model and hence cannot be forcibly included. Please verify the variable names."), call. = FALSE)
+    }
+  }
+
+  if (is.character(exclude)) {
+    npm <- exclude %in% indterms
+    if (!all(npm)) {
+      stop(paste(paste(exclude[!npm], collapse = ", "), "not part of the model and hence cannot be forcibly excluded. Please verify the variable names."), call. = FALSE)
+    }
+  }
+  
+  if (is.numeric(include)) {
+    if (any(include > lenterms)) {
+      stop(paste0("Index of variable to be included should be between 1 and ", lenterms, "."), call. = FALSE)
+    } else {
+      include <- indterms[include]
+    }
+  }
+
+  if (is.numeric(exclude)) {
+    if (any(exclude > lenterms)) {
+      stop(paste0("Index of variable to be excluded should be between 1 and ", lenterms, "."), call. = FALSE)  
+    } else {
+      exclude <- indterms[exclude]
+    }
+  }
+
+  nam   <- setdiff(coeff_names(model), exclude)
   n     <- length(nam)
   r     <- seq_len(n)
   combs <- list()
@@ -65,19 +103,37 @@ ols_step_best_subset.default <- function(model, ...) {
     combs[[i]] <- combn(n, r[i])
   }
 
-  lc        <- length(combs)
+  if (!is.null(max_order)) {
+    check_order(n, max_order)
+  }
+
+  if (is.null(max_order)) {
+    max_order <- n
+  }
+
+  # lc        <- length(combs)
+  lc        <- max_order
   varnames  <- model_colnames(model)
-  predicts  <- nam
-  len_preds <- length(predicts)
-  gap       <- len_preds - 1
-  space     <- coeff_length(predicts, gap)
-  data      <- mod_sel_data(model)
+  data      <- model$model
   colas     <- unname(unlist(lapply(combs, ncol)))
   response  <- varnames[1]
-  p         <- colas
-  t         <- cumsum(colas)
-  q         <- c(1, t[-lc] + 1)
-  
+  predicts  <- list()
+  k         <- 1
+
+  for (i in seq_len(lc)) {
+    for (j in seq_len(colas[i])) {
+      predicts[[k]] <- nam[combs[[i]][, j]]
+      k <- k + 1
+    }
+  }
+
+  if(!is.null(include)) {
+    y <- grep(include, predicts)
+    predicts <- predicts[y]
+  }
+
+  len_elig <- length(predicts)
+
   mcount    <- 0
   rsq       <- list()
   adjr      <- list()
@@ -95,13 +151,10 @@ ols_step_best_subset.default <- function(model, ...) {
   preds     <- list()
   lpreds    <- c()
 
-  for (i in seq_len(lc)) {
-    for (j in seq_len(colas[i])) {
-      predictors        <- nam[combs[[i]][, j]]
+  for (i in seq_len(len_elig)) {
+      predictors        <- predicts[[i]]
       lp                <- length(predictors)
-      out               <- ols_regress(paste(response, "~", 
-                                       paste(predictors, collapse = " + ")), 
-                                       data = data)
+      out               <- ols_regress(paste(response, "~", paste(predictors, collapse = " + ")), data = data)
       mcount            <- mcount + 1
       lpreds[mcount]    <- lp
       rsq[[mcount]]     <- out$rsq
@@ -116,7 +169,6 @@ ols_step_best_subset.default <- function(model, ...) {
       sp[[mcount]]      <- ols_hsp(out$model)
       predrsq[[mcount]] <- ols_pred_rsq(out$model)
       preds[[mcount]]   <- paste(predictors, collapse = " ")
-    }
   }
 
   ui <- data.frame(
@@ -136,31 +188,26 @@ ols_step_best_subset.default <- function(model, ...) {
     stringsAsFactors = F
   )
 
+  metrics <- match.arg(metric)
   sorted <- c()
+  l <- split(ui, ui$n)
 
-  for (i in seq_len(lc)) {
-    temp   <- ui[q[i]:t[i], ]
-    temp   <- temp[order(temp$rsquare, decreasing = TRUE), ]
-    sorted <- rbind(sorted, temp[1, ])
+  if (metrics == "rsquare" || metrics == "adjr" || metrics == "predrsq") {
+    temp <- lapply(l, function(x) x[order(x[[metrics]], decreasing = TRUE), ][1, ])
+  } else {
+    temp <- lapply(l, function(x) x[order(x[[metrics]]), ][1, ])
   }
-
+  
+  sorted <- do.call(rbind, temp)
   mindex <- seq_len(nrow(sorted))
   sorted <- cbind(mindex, sorted)
-
-  class(sorted) <- c("ols_step_best_subset", "data.frame")
-  return(sorted)
+  result <- list(metrics = sorted)
+  class(result) <- c("ols_step_best_subset")
+  
+  return(result)
 
 }
 
-#' @export
-#' @rdname ols_step_best_subset
-#' @usage NULL
-#'
-ols_best_subset <- function(model, ...) {
-  .Deprecated("ols_step_best_subset()")
-}
-
-
 #' @export
 #'
 print.ols_step_best_subset <- function(x, ...) {
@@ -172,18 +219,10 @@ print.ols_step_best_subset <- function(x, ...) {
 #'
 plot.ols_step_best_subset <- function(x, model = NA, print_plot = TRUE, ...) {
 
-  rsquare <- NULL
-  adjr    <- NULL
-  sbic    <- NULL
-  aic     <- NULL
-  sbc     <- NULL
-  cp      <- NULL
-  a       <- NULL
-  b       <- NULL
+  z <- x$metrics
 
-
-  d <- data.frame(mindex = x$mindex, rsquare = x$rsquare, adjr = x$adjr,
-               cp = x$cp, aic = x$aic, sbic = x$sbic, sbc = x$sbc)
+  d <- data.frame(mindex = z$mindex, rsquare = z$rsquare, adjr = z$adjr,
+                  cp = z$cp, aic = z$aic, sbic = z$sbic, sbc = z$sbc)
 
   p1 <- best_subset_plot(d, "rsquare")
   p2 <- best_subset_plot(d, "adjr", title = "Adj. R-Square")
@@ -196,7 +235,7 @@ plot.ols_step_best_subset <- function(x, model = NA, print_plot = TRUE, ...) {
                   plot_4 = p4, plot_5 = p5, plot_6 = p6)
 
   if (print_plot) {
-    marrangeGrob(myplots, nrow = 2, ncol = 2)
+    marrangeGrob(myplots, nrow = 2, ncol = 2, top = "Best Subset Regression")
   } else {
     return(myplots)
   }
@@ -216,17 +255,15 @@ plot.ols_step_best_subset <- function(x, model = NA, print_plot = TRUE, ...) {
 #'
 best_subset_plot <- function(d, var, title = "R-Square") {
 
-  mindex <- NULL
-  a      <- NULL
-  b      <- NULL
-  
-  d1 <- d[, c("mindex", var)]   
+  d1 <- d[, c("mindex", var)]
   colnames(d1) <- c("a", "b")
 
   ggplot(d1, aes(x = a, y = b)) +
     geom_line(color = "blue") +
     geom_point(color = "blue", shape = 1, size = 2) +
-    xlab("") + ylab("") + ggtitle(title) +
+    xlab("") + 
+    ylab("") + 
+    ggtitle(title) +
     theme(axis.ticks = element_blank())
 
 }
