@@ -55,9 +55,6 @@
 #'
 #' Cook, R. D.; Weisberg, S. (1983). "Diagnostics for Heteroskedasticity in Regression". Biometrika. 70 (1): 1–10.
 #'
-#' @section Deprecated Function:
-#' \code{ols_bp_test()} has been deprecated. Instead use \code{ols_test_breusch_pagan()}.
-#'
 #' @family heteroskedasticity tests
 #'
 #' @examples
@@ -175,33 +172,15 @@ ols_test_breusch_pagan.default <- function(model, fitted.values = TRUE, rhs = FA
     }
   }
 
-  out <- list(
-    bp       = bp,
-    p        = p,
-    fv       = fitted.values,
-    rhs      = rhs,
-    multiple = multiple,
-    padj     = method,
-    vars     = vars,
-    resp     = response,
-    preds    = predictors
-  )
+  out <- list(bp = bp, fv = fitted.values, multiple = multiple, p = p,
+              padj = method, preds = predictors, resp = response,
+              rhs = rhs, vars = vars)
 
   class(out) <- "ols_test_breusch_pagan"
 
   return(out)
 }
 
-#' @export
-#' @rdname ols_test_breusch_pagan
-#' @usage NULL
-#'
-ols_bp_test <- function(model, fitted.values = TRUE, rhs = FALSE, multiple = FALSE,
-                        p.adj = c("none", "bonferroni", "sidak", "holm"), vars = NA) {
-  .Deprecated("ols_test_breusch_pagan()")
-}
-
-
 #' @export
 #'
 print.ols_test_breusch_pagan <- function(x, ...) {
