@@ -5,6 +5,8 @@
 #' fitted values of the model.
 #'
 #' @param model An object of class \code{lm}.
+#' @param type An integer between 1 and 5 selecting one of the 6 methods for computing the threshold.
+#' @param threshold Threshold for detecting outliers.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @details
@@ -21,7 +23,25 @@
 #'   \item exmine how much all of the fitted values change when the ith observation is deleted.
 #' }
 #'
-#' A data point having a large cook's d indicates that the data point strongly influences the fitted values.
+#' A data point having a large cook's d indicates that the data point strongly
+#' influences the fitted values. There are several methods/formulas to compute
+#' the threshold used for detecting or classifying observations as outliers
+#' and we list them below.
+#'
+#' \itemize{
+#'   \item \strong{Type 1} : 4 / n
+#'   \item \strong{Type 2} : 4 / (n - k - 1)
+#'   \item \strong{Type 3} : ~1
+#'   \item \strong{Type 4} : 1 / (n - k - 1)
+#'   \item \strong{Type 5} : 3 * mean(Vector of cook's distance values)
+#' }
+#'
+#' where \strong{n} and \strong{k} stand for
+#'
+#' \itemize{
+#'   \item \strong{n}: Number of observations
+#'   \item \strong{k}: Number of predictors
+#' }
 #'
 #' @return \code{ols_plot_cooksd_chart} returns  a list containing the
 #' following components:
@@ -29,12 +49,11 @@
 #' \item{outliers}{a \code{data.frame} with observation number and \code{cooks distance} that exceed \code{threshold}}
 #' \item{threshold}{\code{threshold} for classifying an observation as an outlier}
 #'
-#' @section Deprecated Function:
-#' \code{ols_cooksd_chart()} has been deprecated. Instead use \code{ols_plot_cooksd_chart()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_cooksd_chart(model)
+#' ols_plot_cooksd_chart(model, type = 4)
+#' ols_plot_cooksd_chart(model, threshold = 0.2)
 #'
 #' @importFrom ggplot2 geom_linerange
 #'
@@ -42,44 +61,45 @@
 #'
 #' @export
 #'
-ols_plot_cooksd_chart <- function(model, print_plot = TRUE) {
+ols_plot_cooksd_chart <- function(model, type = 1, threshold = NULL, print_plot = TRUE) {
 
   check_model(model)
 
-  obs <- NULL
-  ckd <- NULL
-  txt <- NULL
-  cd  <- NULL
-
-  k <- ols_prep_cdplot_data(model)
+  k <- ols_prep_cdplot_data(model, type)
   d <- ols_prep_outlier_obs(k)
   f <- ols_prep_cdplot_outliers(k)
 
-  p <- ggplot(d, aes(x = obs, y = cd, label = txt, ymin = min(cd), ymax = cd)) +
-    geom_linerange(colour = "blue") + geom_point(shape = 1, colour = "blue") +
-    geom_hline(yintercept = k$ts, colour = "red") + xlab("Observation") +
-    ylab("Cook's D") + ggtitle("Cook's D Chart") +
+  if (is.null(threshold)) {
+      threshold <- k$ts
+  }
+
+  p <- 
+    ggplot(d, aes(x = obs, y = cd, label = txt, ymin = min(cd), ymax = cd)) +
+    geom_linerange(colour = "blue") + 
+    geom_point(shape = 1, colour = "blue") +
     geom_text(vjust = -1, size = 3, family = "serif", fontface = "italic",
               colour = "darkred", na.rm = TRUE) +
-    annotate(
-      "text", x = Inf, y = Inf, hjust = 1.2, vjust = 2,
+    geom_hline(yintercept = threshold, colour = "red") 
+
+  # annotations
+  p <- 
+    p +
+    annotate("text", x = Inf, y = Inf, hjust = 1.2, vjust = 2,
       family = "serif", fontface = "italic", colour = "darkred",
-      label = paste("Threshold:", round(k$ts, 3))
-    )
+      label = paste("Threshold:", round(threshold, 3)))
+
+  # guides
+  p <-
+    p +
+    xlab("Observation") +
+    ylab("Cook's D") + 
+    ggtitle("Cook's D Chart") 
+    
 
   if (print_plot) {
     suppressWarnings(print(p))
   } else {
-    return(list(plot = p, outliers = f, threshold = k$ts))
+    return(list(plot = p, outliers = f, threshold = threshold))
   }
 
 }
-
-
-#' @export
-#' @rdname ols_plot_cooksd_chart
-#' @usage NULL
-#'
-ols_cooksd_chart <- function(model) {
-  .Deprecated("ols_plot_cooksd_chart()")
-}
