@@ -55,27 +55,8 @@ print.ols_correlations <- function(x, ...) {
   print_correlations(x)
 }
 
-
-cordata <- function(model) {
-  ols_prep_avplot_data(model)
-}
-
-cmdata <- function(mdata) {
-  cor(mdata)[-1, 1]
-}
-
-rtwo <- function(i, mdata) {
-  dat <- mdata[, c(-1, -i)]
-  summary(lm(mdata[[1]] ~ ., data = dat))[[8]]
-}
-
-corsign <- function(model) {
-  sign(summary(model)$coefficients[-1, 1])
-}
-
 corout <- function(model, r2) {
 
-  r.squared        <- NULL
   r1               <- summary(model)$r.squared
   mdata            <- cordata(model)
   cor_mdata        <- cmdata(mdata)
@@ -105,3 +86,20 @@ corm2 <- function(model) {
 
   return(r2)
 }
+
+cordata <- function(model) {
+  ols_prep_avplot_data(model)
+}
+
+cmdata <- function(mdata) {
+  cor(mdata)[-1, 1]
+}
+
+rtwo <- function(i, mdata) {
+  dat <- mdata[, c(-1, -i), drop = FALSE]
+  summary(lm(mdata[[1]] ~ ., data = dat))[[8]]
+}
+
+corsign <- function(model) {
+  sign(summary(model)$coefficients[-1, 1])
+}
\ No newline at end of file
