@@ -8,9 +8,6 @@
 #' @param predictor Predictor variable.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
-#' @section Deprecated Function:
-#' \code{ols_reg_line()} has been deprecated. Instead use \code{ols_plot_reg_line()}.
-#'
 #' @examples
 #' ols_plot_reg_line(mtcars$mpg, mtcars$disp)
 #'
@@ -20,21 +17,20 @@
 #'
 ols_plot_reg_line <- function(response, predictor, print_plot = TRUE) {
 
-  resp        <- l(deparse(substitute(response)))
-  preds       <- l(deparse(substitute(predictor)))
-  m_predictor <- round(mean(predictor), 2)
-  m_response  <- round(mean(response), 2)
-  x           <- NULL
-  y           <- NULL
-  d2          <- data.frame(x = m_predictor, y = m_response)
-  d           <- data.frame(x = predictor, y = response)
+  data <- ols_prep_regline_data(response, predictor)
 
   p <-
-    ggplot(d, aes(x = x, y = y)) + geom_point(fill = "blue") +
-    xlab(paste0(preds)) + ylab(paste0(resp)) + labs(title = "Regression Line") +
-    geom_point(data = d2, aes(x = x, y = y), color = "red", shape = 2, size = 3) +
+    ggplot(data$d, aes(x = x, y = y)) +
+    geom_point(fill = "blue") +
+    geom_point(data = data$d2, aes(x = x, y = y), color = "red", shape = 2, size = 3) +
     geom_smooth(method = "lm", se = FALSE)
 
+  p <-
+    p +
+    labs(title = "Regression Line") +
+    xlab(paste0(data$preds)) +
+    ylab(paste0(data$resp))
+
   if (print_plot) {
     print(p)
   } else {
@@ -43,11 +39,13 @@ ols_plot_reg_line <- function(response, predictor, print_plot = TRUE) {
 
 }
 
+ols_prep_regline_data <- function(response, predictor) {
+  resp        <- l(deparse(substitute(response)))
+  preds       <- l(deparse(substitute(predictor)))
+  m_predictor <- round(mean(predictor), 2)
+  m_response  <- round(mean(response), 2)
+  d2          <- data.frame(x = m_predictor, y = m_response)
+  d           <- data.frame(x = predictor, y = response)
 
-#' @export
-#' @rdname ols_plot_reg_line
-#' @usage NULL
-#'
-ols_reg_line <- function(response, predictor) {
-  .Deprecated("ols_plot_reg_line()")
+  list(d = d, d2 = d2, preds = preds, resp = resp)
 }
