@@ -15,7 +15,7 @@
 #' \item{r}{square root of rsquare, correlation between observed and predicted values of dependent variable}
 #' \item{rsq}{coefficient of determination or r-square}
 #' \item{adjr}{adjusted rsquare}
-#' \item{sigma}{root mean squared error}
+#' \item{rmse}{root mean squared error}
 #' \item{cv}{coefficient of variation}
 #' \item{mse}{mean squared error}
 #' \item{mae}{mean absolute error}
@@ -110,7 +110,7 @@ ols_regress.lm <- function(object, ...) {
   check_model(object)
 
   formula <- formula(object)
-  data    <- eval(object$call$data)
+  data    <- object$model
 
   ols_regress.default(object = formula, data = data)
 
