@@ -5,9 +5,6 @@
 #' @param model An object of class \code{lm}.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
-#' @section Deprecated Function:
-#' \code{ols_rsd_boxplot()} has been deprecated. Instead use \code{ols_plot_resid_box()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_resid_box(model)
@@ -28,9 +25,17 @@ ols_plot_resid_box <- function(model, print_plot = TRUE) {
 
   p <-
     ggplot(d, aes(x = factor(0), y = resid)) +
-    geom_boxplot(outlier.color = "green", outlier.size = 3,
-                 fill = "grey80", colour = "#3366FF") +
-    xlab(" ") + ylab("Residuals") + ggtitle("Residual Box Plot") +
+    geom_boxplot(outlier.color = "green", outlier.size = 3, fill = "grey80",
+                 colour = "#3366FF")
+
+  p <-
+    p +
+    xlab(" ") +
+    ylab("Residuals") +
+    ggtitle("Residual Box Plot")
+
+  p <-
+    p +
     theme(axis.text.x = element_blank())
 
   if (print_plot) {
@@ -40,12 +45,3 @@ ols_plot_resid_box <- function(model, print_plot = TRUE) {
   }
 
 }
-
-
-#' @export
-#' @rdname ols_plot_resid_box
-#' @usage NULL
-#'
-ols_rsd_boxplot <- function(model) {
-  .Deprecated("ols_plot_resid_box()")
-}
