@@ -15,11 +15,6 @@
 #' @references
 #' Cleveland, W. S. (1993). Visualizing Data. Summit, NJ: Hobart Press.
 #'
-#' @section Deprecated Function:
-#' \code{ols_rfs_plot()}, \code{ols_fm_plot()} and \code{ols_rsd_plot()}
-#'   has been deprecated. Instead use \code{ols_plot_resid_fit_spread()},
-#'   \code{ols_plot_fm()} and \code{ols_plot_resid_spread()}.
-#'
 #' @examples
 #' # model
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
@@ -40,28 +35,11 @@
 #'
 ols_plot_resid_fit_spread <- function(model, print_plot = TRUE) {
 
-  check_model(model)
-
-  x     <- NULL
-  y     <- NULL
-  d1    <- ols_prep_rfsplot_fmdata(model)
-  ymin1 <- min(d1$y) + (0.25 * min(d1$y))
-  ymax1 <- max(d1$y) + (0.25 * max(d1$y))
-
-  p1 <- ggplot(d1, aes(x = x, y = y)) + geom_point(shape = 1, color = "blue") +
-    xlim(c(-0.2, 1.2)) + ylim(c(ymin1, ymax1)) + xlab("Proportion Less") +
-    ylab("") + ggtitle("Fit - Mean")
-
-  d2    <- ols_prep_rfsplot_rsdata(model)
-  ymin2 <- min(d2$y) + (0.25 * min(d2$y))
-  ymax2 <- max(d2$y) + (0.25 * max(d2$y))
-
-  p2 <- ggplot(d2, aes(x = x, y = y)) + geom_point(color = "blue", shape = 1) +
-    ylim(c(ymin2, ymax2)) + xlim(c(-0.2, 1.2)) + xlab("Proportion Less") +
-    ylab("") + ggtitle("Residual")
+  p1 <- ols_plot_fm(model, FALSE)
+  p2 <- ols_plot_resid_spread(model, FALSE)
 
   if (print_plot) {
-    grid.arrange(p1, p2, ncol = 2)
+    grid.arrange(p1, p2, ncol = 2, top = "Residual Fit Spread Plot")
   } else {
     return(list(fm_plot = p1, rsd_plot = p2))
   }
@@ -75,16 +53,7 @@ ols_plot_fm <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
-  x    <- NULL
-  y    <- NULL
-  d    <- ols_prep_rfsplot_fmdata(model)
-  ymin <- min(d$y) + (0.25 * min(d$y))
-  ymax <- max(d$y) + (0.25 * max(d$y))
-
-  p <-
-    ggplot(d, aes(x = x, y = y)) + geom_point(shape = 1, color = "blue") +
-    xlim(c(-0.2, 1.2)) + ylim(c(ymin, ymax)) + xlab("Proportion Less") +
-    ylab("Fit - Mean") + ggtitle("Residual Fit Spread Plot")
+  p <- ols_plot_rfs(model)
 
   if (print_plot) {
     print(p)
@@ -102,16 +71,7 @@ ols_plot_resid_spread <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
-  x    <- NULL
-  y    <- NULL
-  d    <- ols_prep_rfsplot_rsdata(model)
-  ymin <- min(d$y) + (0.25 * min(d$y))
-  ymax <- max(d$y) + (0.25 * max(d$y))
-
-  p <-
-    ggplot(d, aes(x = x, y = y)) + geom_point(color = "blue", shape = 1) +
-    ylim(c(ymin, ymax)) + xlim(c(-0.2, 1.2)) + ylab("Residual") +
-    xlab("Proportion Less") + ggtitle("Residual Fit Spread Plot")
+  p <- ols_plot_rfs(model, fit_mean = FALSE)
 
   if (print_plot) {
     print(p)
@@ -122,27 +82,28 @@ ols_plot_resid_spread <- function(model, print_plot = TRUE) {
 }
 
 
-#' @export
-#' @rdname ols_plot_resid_fit_spread
-#' @usage NULL
-#'
-ols_rfs_plot <- function(model) {
-  .Deprecated("ols_plot_resid_fit_spread()")
-}
+ols_plot_rfs <- function(model, fit_mean = TRUE) {
 
+  if (fit_mean) {
+    d <- ols_prep_rfsplot_fmdata(model)  
+    y_lab <- "Fit - Mean"
+  } else {
+    d <- ols_prep_rfsplot_rsdata(model)
+    y_lab <- "Residual"
+  }
 
-#' @export
-#' @rdname ols_plot_resid_fit_spread
-#' @usage NULL
-#'
-ols_rsd_plot <- function(model) {
-  .Deprecated("ols_plot_resid_spread()")
-}
+  ymin <- min(d$y) + (0.25 * min(d$y))
+  ymax <- max(d$y) + (0.25 * max(d$y))
 
-#' @export
-#' @rdname ols_plot_resid_fit_spread
-#' @usage NULL
-#'
-ols_fm_plot <- function(model) {
-  .Deprecated("ols_plot_fm()")
-}
+  p <-
+    ggplot(d, aes(x = x, y = y)) +
+    geom_point(shape = 1, color = "blue") +
+    xlab("Proportion Less") +
+    ylab(y_lab) +
+    ggtitle("Residual Fit Spread Plot") +
+    xlim(c(-0.2, 1.2)) +
+    ylim(c(ymin, ymax))
+
+  return(p)
+
+}
\ No newline at end of file
