@@ -10,9 +10,6 @@
 #' @param variable New predictor to be added to the \code{model}.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
-#' @section Deprecated Function:
-#' \code{ols_rvsr_plot()} has been deprecated. Instead use \code{ols_plot_resid_regressor()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_resid_regressor(model, 'drat')
@@ -25,8 +22,6 @@ ols_plot_resid_regressor <- function(model, variable, print_plot = TRUE) {
 
   check_model(model)
 
-  x     <- NULL
-  y     <- NULL
   d     <- ols_prep_rvsrplot_data(model)
   inter <- eval(model$call$data)[variable]
   x     <- inter[[1]]
@@ -37,23 +32,15 @@ ols_plot_resid_regressor <- function(model, variable, print_plot = TRUE) {
   p <-
     ggplot(k, aes(x = x, y = y)) +
     geom_point(shape = 1, colour = "blue") +
-    xlab(paste(v)) + ylab("Residual") +
-    ggtitle(paste("Residual vs", v)) +
-    geom_hline(yintercept = 0, colour = "red")
+    geom_hline(yintercept = 0, colour = "red") +
+    xlab(paste(v)) +
+    ylab("Residual") +
+    ggtitle(paste("Residual vs", v))
 
   if (print_plot) {
     print(p)
-  } else {
-    return(p)
   }
 
-}
+  return(p)
 
-
-#' @export
-#' @rdname ols_plot_resid_regressor
-#' @usage NULL
-#'
-ols_rvsr_plot <- function(model, variable) {
-  .Deprecated("ols_plot_resid_regressor()")
 }
