@@ -5,9 +5,6 @@
 #' @param model An object of class \code{lm}.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
-#' @section Deprecated Function:
-#' \code{ols_resp_viz()} has been deprecated. Instead use \code{ols_plot_response()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_response(model)
@@ -21,38 +18,11 @@ ols_plot_response <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
-  x <- NULL
-  y <- NULL
-
-  nam       <- names(model.frame(model))
-  predictor <- model.response(model.frame(model))
-  xval      <- seq_len(length(predictor))
-  d1        <- data.frame(x = predictor)
-
-  p1 <- ggplot(d1, aes(x = x)) +
-    geom_dotplot(binwidth = 1, fill = "blue") +
-    xlab(nam[1]) + ggtitle(paste("Dot Plot of", nam[1]))
-
-  d2 <- data.frame(x = xval, y = predictor)
-  p2 <- ggplot(d2, aes(x = x, y = y)) +
-    geom_point(color = "blue") +
-    geom_line(color = "blue") +
-    xlab("Observation") + ylab(nam[1]) +
-    ggtitle(paste("Trend Plot of", nam[1]))
-
-
-  d3 <- data.frame(x = predictor)
-  p3 <- ggplot(d3, aes(x = x)) +
-    geom_histogram(bins = 5, color = "black", fill = "blue") +
-    xlab(nam[1]) + ggtitle(paste("Histogram of", nam[1]))
-
-
-  d4 <- data.frame(x = predictor)
-  p4 <- ggplot(d4, aes(x = factor(0), y = x)) +
-    geom_boxplot(fill = "blue") +
-    xlab("") + ylab(nam[1]) +
-    ggtitle(paste("Boxplot of", nam[1])) +
-    theme(axis.text.x = element_blank())
+  d  <- ols_response_data(model)
+  p1 <- ols_response_dotplot(d$d1, d$nam)
+  p2 <- ols_response_trend(d$d2, d$nam)
+  p3 <- ols_response_hist(d$d1, d$nam)
+  p4 <- ols_response_box(d$d1, d$nam)
 
   if (print_plot) {
     grid.arrange(p1, p2, p3, p4, ncol = 2, top = "Response Diagnostics")
@@ -67,11 +37,44 @@ ols_plot_response <- function(model, print_plot = TRUE) {
 
 }
 
+ols_response_data <- function(model) {
+  nam  <- names(model.frame(model))
+  pred <- model.response(model.frame(model))
+  xval <- seq_len(length(pred))
+  d1   <- data.frame(x = pred)
+  d2   <- data.frame(x = xval, y = pred)
 
-#' @export
-#' @rdname ols_plot_response
-#' @usage NULL
-#'
-ols_resp_viz <- function(model) {
-  .Deprecated("ols_plot_response()")
+  list(nam = nam, d1 = d1, d2 = d2)
+}
+
+ols_response_dotplot <- function(d, nam) {
+  ggplot(d, aes(x = x)) +
+    geom_dotplot(binwidth = 1, fill = "blue") +
+    xlab(nam[1]) +
+    ggtitle(paste("Dot Plot of", nam[1]))
+}
+
+ols_response_trend <- function(d, nam) {
+  ggplot(d, aes(x = x, y = y)) +
+    geom_point(color = "blue") +
+    geom_line(color = "blue") +
+    xlab("Observation") +
+    ylab(nam[1]) +
+    ggtitle(paste("Trend Plot of", nam[1]))
+}
+
+ols_response_hist <- function(d, nam) {
+  ggplot(d, aes(x = x)) +
+    geom_histogram(bins = 5, color = "black", fill = "blue") +
+    xlab(nam[1]) +
+    ggtitle(paste("Histogram of", nam[1]))
+}
+
+ols_response_box <- function(d, nam) {
+  ggplot(d, aes(x = factor(0), y = x)) +
+    geom_boxplot(fill = "blue") +
+    xlab("") +
+    ylab(nam[1]) +
+    ggtitle(paste("Boxplot of", nam[1])) +
+    theme(axis.text.x = element_blank())
 }
