@@ -30,9 +30,6 @@
 #'
 #' Koenker, R. 1981. A note on studentizing a test for heteroskedasticity. Journal of Econometrics 17: 107–112.
 #'
-#' @section Deprecated Function:
-#' \code{ols_score_test()} has been deprecated. Instead use \code{ols_test_score()}.
-#'
 #' @examples
 #' # model
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
@@ -80,14 +77,8 @@ ols_test_score.default <- function(model, fitted_values = TRUE, rhs = FALSE,
     }
   }
 
-  out <- list(score = d$score,
-              p     = d$p,
-              df    = d$np,
-              fv    = fitted_values,
-              rhs   = rhs,
-              preds = d$preds,
-              resp  = resp
-  )
+  out <- list(df = d$np, fv = fitted_values, p = d$p, preds = d$preds,
+              resp = resp, rhs = rhs, score = d$score)
 
   class(out) <- "ols_test_score"
   return(out)
@@ -103,33 +94,22 @@ print.ols_test_score <- function(x, ...) {
 rhsout <- function(model) {
 
   l         <- ols_prep_avplot_data(model)
-  n         <- nrow(l)
   nam       <- names(l)[-1]
-  np        <- length(nam)
-  var_resid <- residual_var(model, n)
+  var_resid <- residual_var(model, nrow(l))
   ind       <- ind_score(model, var_resid)
-  score     <- rhs_score(l, ind, n)
-  p         <- pchisq(score, np, lower.tail = F)
-  preds     <- nam
+  score     <- rhs_score(l, ind, nrow(l))
+  p         <- pchisq(score, length(nam), lower.tail = F)
 
-  list(score = score,
-       preds = preds,
-       np    = np,
-       p     = p)
+  list(score = score, preds = nam, np = length(nam), p = p)
 
 }
 
 fitout <- function(model, resp) {
 
   score <- fit_score(model)
-  np    <- 1
   p     <- pchisq(score, 1, lower.tail = F)
-  preds <- paste("fitted values of", resp)
 
-  list(score = score,
-       preds = preds,
-       np    = np,
-       p     = p)
+  list(score = score, preds = paste("fitted values of", resp), np = 1, p = p)
 
 }
 
@@ -138,13 +118,8 @@ varout <- function(model, vars) {
   score <- var_score(model, vars)
   nd    <- ncol(score_data(model, vars)) - 1
   p     <- pchisq(score, nd, lower.tail = F)
-  np    <- nd
-  preds <- vars
 
-  list(score = score,
-       preds = preds,
-       np    = np,
-       p     = p)
+  list(score = score, preds = vars, np = nd, p = p)
 
 }
 
@@ -161,7 +136,6 @@ ind_score <- function(model, var_resid) {
 
 rhs_score <- function(l, ind, n) {
 
-  r.squared <- NULL
   ind <- data.frame(ind = ind)
   (summary(lm(ind ~ ., data = cbind(l, ind)[, -1]))$r.squared) * n
 
@@ -169,7 +143,6 @@ rhs_score <- function(l, ind, n) {
 
 fit_score <- function(model) {
 
-  r.squared    <- NULL
   pred         <- fitted(model)
   scaled_resid <- resid_scaled(model, pred)
   l            <- ols_prep_avplot_data(model)
@@ -189,7 +162,6 @@ resid_scaled <- function(model, pred) {
 
 var_score <- function(model, vars) {
 
-  r.squared <- NULL
   n <- nrow(ols_prep_avplot_data(model)) 
   (summary(lm(ind ~ ., data = score_data(model, vars)))$r.squared) * n
     
@@ -198,20 +170,9 @@ var_score <- function(model, vars) {
 score_data <- function(model, vars) {
 
   l              <- ols_prep_avplot_data(model)
-  n              <- nrow(l)
-  var_resid      <- residual_var(model, n)
+  var_resid      <- residual_var(model, nrow(l))
   ind            <- as.data.frame(ind_score(model, var_resid)) 
   colnames(ind)  <- c("ind")
 
   cbind(l[, vars], ind)
-}
-
-
-#' @export
-#' @rdname ols_test_score
-#' @usage NULL
-#'
-ols_score_test <- function(model, fitted_values = TRUE, rhs = FALSE,
-                           vars = NULL) {
-  .Deprecated("ols_test_score()")
-}
+}
\ No newline at end of file
