@@ -3,6 +3,7 @@
 #' Chart for identifying outliers.
 #'
 #' @param model An object of class \code{lm}.
+#' @param threshold Threshold for detecting outliers. Default is 2.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @details
@@ -16,12 +17,10 @@
 #' exceed \code{threshold}} for classifying an observation as an outlier
 #' \item{threshold}{\code{threshold} for classifying an observation as an outlier}
 #'
-#' @section Deprecated Function:
-#' \code{ols_srsd_chart()} has been deprecated. Instead use \code{ols_plot_resid_stand()}.
-#'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
 #' ols_plot_resid_stand(model)
+#' ols_plot_resid_stand(model, threshold = 3)
 #'
 #' @importFrom stats rstandard
 #'
@@ -29,48 +28,43 @@
 #'
 #' @export
 #'
-ols_plot_resid_stand <- function(model, print_plot = TRUE) {
+ols_plot_resid_stand <- function(model, threshold = NULL, print_plot = TRUE) {
 
   check_model(model)
 
-  color <- NULL
-  obs   <- NULL
-  sdres <- NULL
-  txt   <- NULL
+  if (is.null(threshold)) {
+    threshold <- 2
+  }
 
-  d <- ols_prep_srchart_data(model)
-  f <- d[color == "outlier", c("obs", "sdres")]
+  d <- ols_prep_srchart_data(model, threshold)
+  f <- d[d$color == "outlier", c("obs", "sdres")]
   colnames(f) <- c("observation", "stand_resid")
 
   p <-
     ggplot(d, aes(x = obs, y = sdres, label = txt, ymin = 0, ymax = sdres)) +
-    geom_linerange(colour = "blue") + geom_point(shape = 1, colour = "blue") +
-    geom_hline(yintercept = 0, colour = "gray") +
-    geom_hline(yintercept = c(2, -2), colour = "red") +
-    xlab("Observation") + ylab("Standardized Residuals") +
-    ggtitle("Standardized Residuals Chart") +
+    geom_linerange(colour = "blue") +
+    geom_point(shape = 1, colour = "blue") +
     geom_text(hjust = -0.2, nudge_x = 0.15, size = 3, family = "serif",
               fontface = "italic", colour = "darkred", na.rm = TRUE) +
+    geom_hline(yintercept = 0, colour = "gray") +
+    geom_hline(yintercept = c(threshold, -threshold), colour = "red")
+
+  p <-
+    p +
     annotate("text", x = Inf, y = Inf, hjust = 1.5, vjust = 2, family = "serif",
              fontface = "italic", colour = "darkred",
-             label = paste0("Threshold: abs(", 2, ")"))
+             label = paste0("Threshold: abs(", threshold, ")"))
+
+  p <-
+    p +
+    xlab("Observation") +
+    ylab("Standardized Residuals") +
+    ggtitle("Standardized Residuals Chart")
 
   if (print_plot) {
     suppressWarnings(print(p))
   } else {
-    return(
-      list(plot      = p,
-           outliers  = f,
-           threshold = 2)
-      )
+    return(list(plot = p, outliers = f, threshold = threshold))
   }
 
 }
-
-#' @export
-#' @rdname ols_plot_resid_stand
-#' @usage NULL
-#'
-ols_srsd_chart <- function(model) {
-  .Deprecated("ols_plot_resid_stand()")
-}
