@@ -2,15 +2,15 @@ print_reg <- function(data) {
 
   # width
   # prints
-  a <- c("R", "R-Squared", "Adj. R-Squared", "Pred R-Squared")
+  a <- c("R", "R-Squared", "Adj. R-Squared", "Pred R-Squared", "MAE")
   b <- c(
-    format(round(data$r, 3), nsmall = 3), format(round(data$rsq, 3), nsmall = 3), format(round(data$adjr, 3), nsmall = 3),
-    format(round(data$prsq, 3), nsmall = 3)
+    format(round(data$r, 3), nsmall = 3), format(round(data$rsq, 3), nsmall = 3), format(round(data$adjr, 3), nsmall = 3), 
+    format(round(data$prsq, 3), nsmall = 3), format(round(data$mae, 3), nsmall = 3)
   )
-  d <- c("RMSE", "Coef. Var", "MSE", "MAE")
+  d <- c("RMSE", "MSE", "Coef. Var", "AIC", "SBC")
   e <- c(
-    format(round(data$sigma, 3), nsmall = 3), format(round(data$cv, 3), nsmall = 3), format(round(data$mse, 3), nsmall = 3),
-    format(round(data$mae, 3), nsmall = 3)
+    format(round(data$rmse, 3), nsmall = 3), format(round(data$mse, 3), nsmall = 3), format(round(data$cv, 3), nsmall = 3),
+    format(round(data$aic, 3), nsmall = 3), format(round(data$sbc, 3), nsmall = 3)
   )
 
   w1 <- max(nchar(a))
@@ -27,7 +27,7 @@ print_reg <- function(data) {
     cat(fl(a[i], w1), fs(), fs(), fs(), fg(b[i], w2), fs(), fs(), fl(d[i], w3), fs(), fs(), fs(), fg(e[i], w4), "\n")
   }
   cat(rep("-", w5), sep = "", "\n")
-  cat(" RMSE: Root Mean Square Error", "\n", "MSE: Mean Square Error", "\n", "MAE: Mean Absolute Error", "\n\n")
+  cat(" RMSE: Root Mean Square Error", "\n", "MSE: Mean Square Error", "\n", "MAE: Mean Absolute Error", "\n", "AIC: Akaike Information Criteria", "\n", "SBC: Schwarz Bayesian Criteria", "\n\n")
 
   # anova
   w7 <- nchar("Regression")
@@ -593,71 +593,22 @@ print_score_test <- function(data) {
   )
 }
 
-
-
-print_step_backward <- function(data) {
-  n <- data$steps
-
-  if (n < 1) {
-    stop("No variables have been removed from the model based on p-values.")
-  }
-
-  # width
-  w1 <- nchar("Step")
-  w2 <- max(nchar("Variable"), nchar(data$removed))
-  w3 <- max(nchar("R-Square"), nchar(format(round(data$rsquare, 4), nsmall = 4)))
-  w4 <- max(nchar("R-Square"), nchar(format(round(data$adjr, 3), nsmall = 4)))
-  w5 <- max(nchar("C(p)"), nchar(format(round(data$mallows_cp, 4), nsmall = 4)))
-  w6 <- max(nchar("AIC"), nchar(format(round(data$aic, 4), nsmall = 4)))
-  w7 <- max(nchar("RMSE"), nchar(format(round(data$rmse, 4), nsmall = 4)))
-  w <- sum(w1, w2, w3, w4, w5, w6, w7, 24)
-
-  cat("\n\n")
-  cat(format("Elimination Summary", justify = "centre", width = w), "\n")
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    format("", width = w1), fs(), format("Variable", width = w2), fs(),
-    format("", width = w3), fs(), format("Adj.", width = w4, justify = "centre"), fs(),
-    format("", width = w5), fs(), format("", width = w6), fs(),
-    format("", width = w7), fs(), "\n"
-  )
-  cat(
-    format("Step", width = w1, justify = "centre"), fs(), format("Removed", width = w2, justify = "centre"), fs(),
-    format("R-Square", width = w3, justify = "centre"), fs(), format("R-Square", width = w4, justify = "centre"), fs(),
-    format("C(p)", width = w5, justify = "centre"), fs(), format("AIC", width = w6, justify = "centre"), fs(),
-    format("RMSE", width = w7, justify = "centre"), fs(), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-
-  for (i in seq_len(n)) {
-    cat(
-      format(i, width = w1), fs(), format(data$removed[i], width = w2), fs(),
-      format(round(data$rsquare[i], 4), width = w3, nsmall = 3), fs(), format(round(data$adjr[i], 4), width = w4, nsmall = 3), fs(),
-      format(round(data$mallows_cp[i], 4), width = w5, justify = "centre", nsmall = 4), fs(),
-      format(round(data$aic[i], 4), width = w6, nsmall = 4), fs(), format(round(data$rmse[i], 4), width = w7, nsmall = 4), fs(), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n")
-}
-
-
-
 print_best_subset <- function(data) {
   w1 <- 11
-  w2 <- max(nchar(data$predictors))
+  w2 <- max(nchar(data$metrics$predictors))
   w <- sum(w1, w2, 4)
 
   w3 <- nchar("Model")
   w4 <- nchar("R-Square")
-  w5 <- max(nchar("Pred"), nchar(format(round(data$predrsq, 4), nsmall = 4)))
-  w6 <- max(nchar("C(p)"), nchar(format(round(data$cp, 4), nsmall = 4)))
-  w7 <- max(nchar("AIC"), nchar(format(round(data$aic, 4), nsmall = 4)))
-  w8 <- max(nchar("SBIC"), nchar(format(round(data$sbic, 4), nsmall = 4)))
-  w9 <- max(nchar("SBC"), nchar(format(round(data$sbc, 4), nsmall = 4)))
-  w10 <- max(nchar("MSEP"), nchar(format(round(data$msep, 4), nsmall = 4)))
-  w11 <- max(nchar("FPE"), nchar(format(round(data$fpe, 4), nsmall = 4)))
-  w12 <- max(nchar("HSP"), nchar(format(round(data$hsp, 4), nsmall = 4)))
-  w13 <- max(nchar("APC"), nchar(format(round(data$apc, 4), nsmall = 4)))
+  w5 <- max(nchar("Pred"), nchar(format(round(data$metrics$predrsq, 4), nsmall = 4)))
+  w6 <- max(nchar("C(p)"), nchar(format(round(data$metrics$cp, 4), nsmall = 4)))
+  w7 <- max(nchar("AIC"), nchar(format(round(data$metrics$aic, 4), nsmall = 4)))
+  w8 <- max(nchar("SBIC"), nchar(format(round(data$metrics$sbic, 4), nsmall = 4)))
+  w9 <- max(nchar("SBC"), nchar(format(round(data$metrics$sbc, 4), nsmall = 4)))
+  w10 <- max(nchar("MSEP"), nchar(format(round(data$metrics$msep, 4), nsmall = 4)))
+  w11 <- max(nchar("FPE"), nchar(format(round(data$metrics$fpe, 4), nsmall = 4)))
+  w12 <- max(nchar("HSP"), nchar(format(round(data$metrics$hsp, 4), nsmall = 4)))
+  w13 <- max(nchar("APC"), nchar(format(round(data$metrics$apc, 4), nsmall = 4)))
 
   v <- sum(w3, w4, w4, w4, w6, w7, w8, w9, w10, w11, w12, w13, 44)
 
@@ -665,10 +616,10 @@ print_best_subset <- function(data) {
   cat("\n", rep("-", w), sep = "", "\n")
   cat("Model Index    Predictors")
   cat("\n", rep("-", w), sep = "", "\n")
-  for (i in data$mindex) {
+  for (i in data$metrics$mindex) {
     cat(
-      format(as.character(data$mindex[i]), width = w1, justify = "centre"), fs(),
-      format(data$predictors[i], width = w2), "\n"
+      format(as.character(data$metrics$mindex[i]), width = w1, justify = "centre"), fs(),
+      format(data$metrics$predictors[i], width = w2), "\n"
     )
   }
   cat(rep("-", w), sep = "", "\n\n")
@@ -676,36 +627,48 @@ print_best_subset <- function(data) {
   cat(format("Subsets Regression Summary", width = v, justify = "centre"))
   cat("\n", rep("-", v), sep = "", "\n")
   cat(
-    format("", width = w3, justify = "centre"), fs(), format("", width = w4, justify = "centre"), fs(),
-    format("Adj.", width = w4, justify = "centre"), fs(), format("Pred", width = w4, justify = "centre"), fs(),
-    format("", width = w6, justify = "centre"), fs(), format("", width = w7, justify = "centre"), fs(),
-    format("", width = w8, justify = "centre"), fs(), format("", width = w9, justify = "centre"), fs(),
-    format("", width = w10, justify = "centre"), fs(), format("", width = w11, justify = "centre"), fs(),
-    format("", width = w12, justify = "centre"), fs(), format("", width = w13, justify = "centre"), "\n"
+    format("", width = w3, justify = "centre"), fs(), 
+    format("", width = w4, justify = "centre"), fs(),
+    format("Adj.", width = w4, justify = "centre"), fs(), 
+    format("Pred", width = w4, justify = "centre"), fs(),
+    format("", width = w6, justify = "centre"), fs(), 
+    format("", width = w7, justify = "centre"), fs(),
+    format("", width = w8, justify = "centre"), fs(), 
+    format("", width = w9, justify = "centre"), fs(),
+    format("", width = w10, justify = "centre"), fs(), 
+    format("", width = w11, justify = "centre"), fs(),
+    format("", width = w12, justify = "centre"), fs(), 
+    format("", width = w13, justify = "centre"), "\n"
   )
   cat(
-    format("Model", width = w3, justify = "centre"), fs(), format("R-Square", width = w4, justify = "centre"), fs(),
-    format("R-Square", width = w4, justify = "centre"), fs(), format("R-Square", width = w4, justify = "centre"), fs(),
-    format("C(p)", width = w6, justify = "centre"), fs(), format("AIC", width = w7, justify = "centre"), fs(),
-    format("SBIC", width = w8, justify = "centre"), fs(), format("SBC", width = w9, justify = "centre"), fs(),
-    format("MSEP", width = w10, justify = "centre"), fs(), format("FPE", width = w11, justify = "centre"), fs(),
-    format("HSP", width = w12, justify = "centre"), fs(), format("APC", width = w13, justify = "centre")
+    format("Model", width = w3, justify = "centre"), fs(), 
+    format("R-Square", width = w4, justify = "centre"), fs(),
+    format("R-Square", width = w4, justify = "centre"), fs(), 
+    format("R-Square", width = w4, justify = "centre"), fs(),
+    format("C(p)", width = w6, justify = "centre"), fs(), 
+    format("AIC", width = w7, justify = "centre"), fs(),
+    format("SBIC", width = w8, justify = "centre"), fs(), 
+    format("SBC", width = w9, justify = "centre"), fs(),
+    format("MSEP", width = w10, justify = "centre"), fs(), 
+    format("FPE", width = w11, justify = "centre"), fs(),
+    format("HSP", width = w12, justify = "centre"), fs(), 
+    format("APC", width = w13, justify = "centre")
   )
   cat("\n", rep("-", v), sep = "", "\n")
-  for (i in data$mindex) {
+  for (i in data$metrics$mindex) {
     cat(
-      format(as.character(data$mindex[i]), width = w3, justify = "centre"), fs(),
-      format(round(data$rsquare[i], 4), nsmall = 4, width = w4, justify = "centre"), fs(),
-      format(round(data$adjr[i], 4), nsmall = 4, width = w4, justify = "centre"), fs(),
-      format(round(data$predrsq[i], 4), width = w4, justify = "centre"), fs(),
-      format(round(data$cp[i], 4), nsmall = 4, width = w6, justify = "centre"), fs(),
-      format(round(data$aic[i], 4), nsmall = 4, width = w7, justify = "centre"), fs(),
-      format(round(data$sbic[i], 4), nsmall = 4, width = w8, justify = "centre"), fs(),
-      format(round(data$sbc[i], 4), nsmall = 4, width = w9, justify = "centre"), fs(),
-      format(round(data$msep[i], 4), nsmall = 4, width = w10, justify = "centre"), fs(),
-      format(round(data$fpe[i], 4), nsmall = 4, width = w11, justify = "centre"), fs(),
-      format(round(data$hsp[i], 4), nsmall = 4, width = w12, justify = "centre"), fs(),
-      format(round(data$apc[i], 4), nsmall = 4, width = w13, justify = "centre"), "\n"
+      format(as.character(data$metrics$mindex[i]), width = w3, justify = "centre"), fs(),
+      format(round(data$metrics$rsquare[i], 4), nsmall = 4, width = w4, justify = "centre"), fs(),
+      format(round(data$metrics$adjr[i], 4), nsmall = 4, width = w4, justify = "centre"), fs(),
+      format(round(data$metrics$predrsq[i], 4), width = w4, justify = "centre"), fs(),
+      format(round(data$metrics$cp[i], 4), nsmall = 4, width = w6, justify = "centre"), fs(),
+      format(round(data$metrics$aic[i], 4), nsmall = 4, width = w7, justify = "centre"), fs(),
+      format(round(data$metrics$sbic[i], 4), nsmall = 4, width = w8, justify = "centre"), fs(),
+      format(round(data$metrics$sbc[i], 4), nsmall = 4, width = w9, justify = "centre"), fs(),
+      format(round(data$metrics$msep[i], 4), nsmall = 4, width = w10, justify = "centre"), fs(),
+      format(round(data$metrics$fpe[i], 4), nsmall = 4, width = w11, justify = "centre"), fs(),
+      format(round(data$metrics$hsp[i], 4), nsmall = 4, width = w12, justify = "centre"), fs(),
+      format(round(data$metrics$apc[i], 4), nsmall = 4, width = w13, justify = "centre"), "\n"
     )
   }
   cat(rep("-", v), sep = "", "\n")
@@ -717,223 +680,6 @@ print_best_subset <- function(data) {
   )
 }
 
-
-
-print_step_forward <- function(data) {
-  n <- length(data$predictors)
-
-  if (n < 1) {
-    stop("No variables have been added to the model based on p-values.")
-  }
-
-  # width
-  w1 <- nchar("Step")
-  w2 <- max(nchar("Variable"), nchar(data$predictors))
-  w3 <- max(nchar("R-Square"), nchar(format(round(data$rsquare, 4), nsmall = 4)))
-  w4 <- max(nchar("R-Square"), nchar(format(round(data$adjr, 4), nsmall = 4)))
-  w5 <- max(nchar("C(p)"), nchar(format(round(data$mallows_cp, 4), nsmall = 4)))
-  w6 <- max(nchar("AIC"), nchar(format(round(data$aic, 4), nsmall = 4)))
-  w7 <- max(nchar("RMSE"), nchar(format(round(data$rmse, 4), nsmall = 4)))
-  w <- sum(w1, w2, w3, w4, w5, w6, w7, 24)
-
-  cat("\n")
-  cat(format("Selection Summary", justify = "centre", width = w), "\n")
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    format("", width = w1), fs(), format("Variable", width = w2), fs(),
-    format("", width = w3), fs(), format("Adj.", width = w4, justify = "centre"), fs(),
-    format("", width = w5), fs(), format("", width = w6), fs(),
-    format("", width = w7), fs(), "\n"
-  )
-  cat(
-    format("Step", width = w1, justify = "centre"), fs(), format("Entered", width = w2, justify = "centre"), fs(),
-    format("R-Square", width = w3, justify = "centre"), fs(), format("R-Square", width = w4, justify = "centre"), fs(),
-    format("C(p)", width = w5, justify = "centre"), fs(), format("AIC", width = w6, justify = "centre"), fs(),
-    format("RMSE", width = w7, justify = "centre"), fs(), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-
-  for (i in seq_len(n)) {
-    cat(
-      format(i, width = w1), fs(), format(data$predictors[i], width = w2), fs(),
-      format(round(data$rsquare[i], 4), width = w3, nsmall = 4), fs(),
-      format(round(data$adjr[i], 4), width = w4, nsmall = 4), fs(),
-      format(round(data$mallows_cp[i], 4), width = w5, justify = "centre", nsmall = 4), fs(),
-      format(round(data$aic[i], 4), width = w6, nsmall = 4), fs(), format(round(data$rmse[i], 4), width = w7, nsmall = 4), fs(), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n")
-}
-
-
-
-print_stepwise <- function(data) {
-  n <- data$steps
-
-  if (n < 1) {
-    stop("No variables have been added to or removed from the model based on p-values.")
-  }
-
-  # width
-  w1 <- nchar("Step")
-  w2 <- max(nchar("Variable"), nchar(data$orders))
-  w8 <- max(nchar("Removed"), nchar(data$method))
-  w3 <- max(nchar("R-Square"), nchar(format(round(data$rsquare, 3), nsmall = 3)))
-  w4 <- max(nchar("R-Square"), nchar(format(round(data$adjr, 3), nsmall = 3)))
-  w5 <- max(nchar("C(p)"), nchar(format(round(data$mallows_cp, 4), nsmall = 4)))
-  w6 <- max(nchar("AIC"), nchar(format(round(data$aic, 4), nsmall = 4)))
-  w7 <- max(nchar("RMSE"), nchar(format(round(data$rmse, 4), nsmall = 4)))
-  w <- sum(w1, w2, w3, w4, w5, w6, w7, w8, 28)
-
-  cat("\n")
-  cat(format("Stepwise Selection Summary", justify = "centre", width = w), "\n")
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    format("", width = w1), fs(), format("", width = w2), fs(), format("Added/", width = w8, justify = "centre"), fs(),
-    format("", width = w3), fs(), format("Adj.", width = w4, justify = "centre"), fs(),
-    format("", width = w5), fs(), format("", width = w6), fs(),
-    format("", width = w7), fs(), "\n"
-  )
-  cat(
-    format("Step", width = w1, justify = "centre"), fs(), format("Variable", width = w2, justify = "centre"), fs(),
-    format("Removed", width = w8, justify = "centre"), fs(),
-    format("R-Square", width = w3, justify = "centre"), fs(), format("R-Square", width = w4, justify = "centre"), fs(),
-    format("C(p)", width = w5, justify = "centre"), fs(), format("AIC", width = w6, justify = "centre"), fs(),
-    format("RMSE", width = w7, justify = "centre"), fs(), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-
-  for (i in seq_len(n)) {
-    cat(
-      format(i, width = w1, justify = "centre"), fs(), format(data$orders[i], width = w2, justify = "centre"), fs(),
-      format(data$method[i], width = w8), fs(), format(round(data$rsquare[i], 3), width = w3, nsmall = 3), fs(),
-      format(round(data$adjr[i], 3), width = w4, nsmall = 3), fs(),
-      format(round(data$mallows_cp[i], 3), width = w5, justify = "centre", nsmall = 4), fs(),
-      format(round(data$aic[i], 4), width = w6, nsmall = 4), fs(), format(round(data$rmse[i], 4), width = w7, nsmall = 4), fs(), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n")
-}
-
-
-
-print_stepaic_forward <- function(data) {
-  if (data$steps < 1) {
-    stop("No variables have been added to the model.")
-  }
-
-  # width
-  w1 <- max(nchar("Predictor"), nchar(data$predictors))
-  w2 <- max(nchar("AIC"), nchar(format(round(data$aics, 3), nsmall = 3)))
-  w3 <- max(nchar("Sum Sq"), nchar(format(round(data$rss, 3), nsmall = 3)))
-  w4 <- max(nchar("RSS"), nchar(format(round(data$ess, 3), nsmall = 3)))
-  w5 <- max(nchar("R-Sq"), nchar(format(round(data$rsq, 5), nsmall = 5)))
-  w6 <- max(nchar("Adj. R-Sq"), nchar(format(round(data$arsq, 5), nsmall = 5)))
-  w <- sum(w1, w2, w3, w4, w5, w6, 20)
-
-  ln <- length(data$aics)
-
-  cat("\n")
-  cat(format("Selection Summary", justify = "centre", width = w), "\n")
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    fl("Variable", w1), fs(), fc("AIC", w2), fs(),
-    fc("Sum Sq", w3), fs(), fc("RSS", w4), fs(), fc("R-Sq", w5), fs(),
-    fc("Adj. R-Sq", w6), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-  for (i in seq_len(ln)) {
-    cat(
-      fl(data$predictors[i], w1), fs(), fg(format(round(data$aics[i], 3), nsmall = 3), w2), fs(),
-      fg(format(round(data$rss[i], 3), nsmall = 3), w3), fs(), fg(format(round(data$ess[i], 3), nsmall = 3), w4), fs(),
-      fg(format(round(data$rsq[i], 5), nsmall = 5), w5), fs(), fg(format(round(data$arsq[i], 5), nsmall = 5), w6), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n")
-}
-
-
-
-print_stepaic_backward <- function(data) {
-  if (data$steps < 1) {
-    stop("No variables have been removed from the model.")
-  }
-
-  # width
-  w1 <- max(nchar("Full Model"), nchar(data$predictors))
-  w2 <- max(nchar("AIC"), nchar(format(round(data$aics, 3), nsmall = 3)))
-  w3 <- max(nchar("RSS"), nchar(format(round(data$ess, 3), nsmall = 3)))
-  w4 <- max(nchar("Sum Sq"), nchar(format(round(data$rss, 3), nsmall = 3)))
-  w5 <- max(nchar("R-Sq"), nchar(format(round(data$rsq, 5), nsmall = 5)))
-  w6 <- max(nchar("Adj. R-Sq"), nchar(format(round(data$arsq, 5), nsmall = 5)))
-  w <- sum(w1, w2, w3, w4, w5, w6, 20)
-
-  predictors <- c("Full Model", data$predictors)
-
-  ln <- length(data$aics)
-
-  cat("\n\n", format("Backward Elimination Summary", width = w, justify = "centre"), "\n")
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    fl("Variable", w1), fs(), fc("AIC", w2), fs(),
-    fc("RSS", w3), fs(), fc("Sum Sq", w4), fs(), fc("R-Sq", w5), fs(),
-    fc("Adj. R-Sq", w6), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-  for (i in seq_len(ln)) {
-    cat(
-      fl(predictors[i], w1), fs(), fg(format(round(data$aics[i], 3), nsmall = 3), w2), fs(),
-      fg(format(round(data$ess[i], 3), nsmall = 3), w3), fs(),
-      fg(format(round(data$rss[i], 3), nsmall = 3), w4), fs(),
-      fg(format(round(data$rsq[i], 5), nsmall = 5), w5), fs(),
-      fg(format(round(data$arsq[i], 5), nsmall = 5), w6), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n\n")
-}
-
-
-
-print_stepaic_both <- function(data) {
-  if (data$steps < 1) {
-    stop("No variables have been added to or removed from the model.")
-  }
-
-  # width
-  w1 <- max(nchar("Variable"), nchar(data$predictors))
-  w2 <- max(nchar("AIC"), nchar(format(round(data$aic, 3), nsmall = 3)))
-  w3 <- max(nchar("RSS"), nchar(format(round(data$ess, 3), nsmall = 3)))
-  w4 <- max(nchar("Sum Sq"), nchar(format(round(data$rss, 3), nsmall = 3)))
-  w5 <- max(nchar("R-Sq"), nchar(format(round(data$rsq, 5), nsmall = 5)))
-  w6 <- max(nchar("Adj. R-Sq"), nchar(format(round(data$arsq, 5), nsmall = 5)))
-  w7 <- nchar("Addition")
-  w <- sum(w1, w2, w3, w4, w5, w6, w7, 24)
-
-  ln <- length(data$aic)
-
-  cat("\n\n", format("Stepwise Summary", width = w, justify = "centre"), "\n")
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    fl("Variable", w1), fs(), fc("Method", w7), fs(), fc("AIC", w2), fs(),
-    fc("RSS", w3), fs(), fc("Sum Sq", w4), fs(), fc("R-Sq", w5), fs(),
-    fc("Adj. R-Sq", w6), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-  for (i in seq_len(ln)) {
-    cat(
-      fl(data$predictors[i], w1), fs(), fl(data$method[i], w7), fs(),
-      fg(format(round(data$aic[i], 3), nsmall = 3), w2), fs(),
-      fg(format(round(data$ess[i], 3), nsmall = 3), w3), fs(),
-      fg(format(round(data$rss[i], 3), nsmall = 3), w4), fs(),
-      fg(format(round(data$rsq[i], 5), nsmall = 5), w5), fs(),
-      fg(format(round(data$arsq[i], 5), nsmall = 5), w6), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n\n")
-}
-
-
-
 print_norm_test <- function(data) {
 
   # width
@@ -1027,3 +773,15 @@ print_pure_error_anova <- function(data) {
   )
   cat(rep("-", w), sep = "", "\n")
 }
+
+print_step_rsquared <- function(data) {
+
+  if (data$others$direction == "forward") {
+    print_step_output(data, "forward")
+  } else if (data$others$direction == "backward") {
+    print_step_output(data, "backward")
+  } else {
+    print_step_output(data, "both")
+  }
+
+}
\ No newline at end of file
