@@ -1,30 +1,27 @@
-## ---- echo=FALSE, message=FALSE------------------------------------------
+## ----echo=FALSE, message=FALSE------------------------------------------------
 library(olsrr)
-library(dplyr)
 library(ggplot2)
 library(gridExtra)
-library(purrr)
-library(tibble)
 library(nortest)
 library(goftest)
 
-## ----qqresid, fig.width=5, fig.height=5, fig.align='center'--------------
+## ----qqresid, fig.width=5, fig.height=5, fig.align='center'-------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 ols_plot_resid_qq(model)
 
-## ----normtest------------------------------------------------------------
+## ----normtest-----------------------------------------------------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 ols_test_normality(model)
 
-## ----corrtest------------------------------------------------------------
+## ----corrtest-----------------------------------------------------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 ols_test_correlation(model)
 
-## ----rvsfplot, fig.width=5, fig.height=5, fig.align='center'-------------
+## ----rvsfplot, fig.width=5, fig.height=5, fig.align='center'------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 ols_plot_resid_fit(model)
 
-## ----residhist, fig.width=5, fig.height=5, fig.align='center'------------
+## ----residhist, fig.width=5, fig.height=5, fig.align='center'-----------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
 ols_plot_resid_hist(model)
 
